==> devextreme-angular-16.2.5.jar: META-INF/resources/webjars/devextreme-angular/16.2.5/ui/data-grid.d.ts <==
/*!
 * devextreme-angular
 * Version: 16.2.5
 * Build date: Tue Feb 28 2017
 *
 * Copyright (c) 2012 - 2017 Developer Express Inc. ALL RIGHTS RESERVED
 *
 * This software may be modified and distributed under the terms
 * of the MIT license. See the LICENSE file in the root of the project for details.
 *
 * https://github.com/DevExpress/devextreme-angular
 */
import { ElementRef, NgZone, OnDestroy, AfterViewInit, OnChanges, DoCheck, SimpleChanges, QueryList } from '@angular/core';
import DxDataGrid from 'devextreme/ui/data_grid';
import { DxComponent } from '../core/component';
import { DxTemplateHost } from '../core/template-host';
import { NestedOptionHost } from '../core/nested-option';
import { WatcherHelper } from '../core/watcher-helper';
import { IterableDifferHelper } from '../core/iterable-differ-helper';
import { DxiColumnComponent } from './nested/column-dxi';
import { DxiSortByGroupSummaryInfoComponent } from './nested/sort-by-group-summary-info-dxi';
export declare class DxDataGridComponent extends DxComponent implements OnDestroy, AfterViewInit, OnChanges, DoCheck {
    private _watcherHelper;
    private _idh;
    instance: DxDataGrid;
    elementAttr: any;
    height: any;
    rtlEnabled: any;
    width: any;
    accessKey: any;
    activeStateEnabled: any;
    disabled: any;
    focusStateEnabled: any;
    hint: any;
    hoverStateEnabled: any;
    tabIndex: any;
    visible: any;
    allowColumnReordering: any;
    allowColumnResizing: any;
    cacheEnabled: any;
    cellHintEnabled: any;
    columnAutoWidth: any;
    columnChooser: any;
    columnFixing: any;
    columnHidingEnabled: any;
    columns: any;
    customizeColumns: any;
    customizeExportData: any;
    dataSource: any;
    editing: any;
    errorRowEnabled: any;
    export: any;
    filterRow: any;
    grouping: any;
    groupPanel: any;
    headerFilter: any;
    loadPanel: any;
    masterDetail: any;
    noDataText: any;
    pager: any;
    paging: any;
    remoteOperations: any;
    rowAlternationEnabled: any;
    rowTemplate: any;
    scrolling: any;
    searchPanel: any;
    selectedRowKeys: any;
    selection: any;
    selectionFilter: any;
    showBorders: any;
    showColumnHeaders: any;
    showColumnLines: any;
    showRowLines: any;
    sortByGroupSummaryInfo: any;
    sorting: any;
    stateStoring: any;
    summary: any;
    twoWayBindingEnabled: any;
    wordWrapEnabled: any;
    onDisposing: any;
    onInitialized: any;
    onOptionChanged: any;
    onContentReady: any;
    onAdaptiveDetailRowPreparing: any;
    onCellClick: any;
    onCellHoverChanged: any;
    onCellPrepared: any;
    onContextMenuPreparing: any;
    onDataErrorOccurred: any;
    onEditingStart: any;
    onEditorPrepared: any;
    onEditorPreparing: any;
    onExported: any;
    onExporting: any;
    onFileSaving: any;
    onInitNewRow: any;
    onKeyDown: any;
    onRowClick: any;
    onRowCollapsed: any;
    onRowCollapsing: any;
    onRowExpanded: any;
    onRowExpanding: any;
    onRowInserted: any;
    onRowInserting: any;
    onRowPrepared: any;
    onRowRemoved: any;
    onRowRemoving: any;
    onRowUpdated: any;
    onRowUpdating: any;
    onRowValidating: any;
    onSelectionChanged: any;
    onToolbarPreparing: any;
    elementAttrChange: any;
    heightChange: any;
    rtlEnabledChange: any;
    widthChange: any;
    accessKeyChange: any;
    activeStateEnabledChange: any;
    disabledChange: any;
    focusStateEnabledChange: any;
    hintChange: any;
    hoverStateEnabledChange: any;
    tabIndexChange: any;
    visibleChange: any;
    allowColumnReorderingChange: any;
    allowColumnResizingChange: any;
    cacheEnabledChange: any;
    cellHintEnabledChange: any;
    columnAutoWidthChange: any;
    columnChooserChange: any;
    columnFixingChange: any;
    columnHidingEnabledChange: any;
    columnsChange: any;
    customizeColumnsChange: any;
    customizeExportDataChange: any;
    dataSourceChange: any;
    editingChange: any;
    errorRowEnabledChange: any;
    exportChange: any;
    filterRowChange: any;
    groupingChange: any;
    groupPanelChange: any;
    headerFilterChange: any;
    loadPanelChange: any;
    masterDetailChange: any;
    noDataTextChange: any;
    pagerChange: any;
    pagingChange: any;
    remoteOperationsChange: any;
    rowAlternationEnabledChange: any;
    rowTemplateChange: any;
    scrollingChange: any;
    searchPanelChange: any;
    selectedRowKeysChange: any;
    selectionChange: any;
    selectionFilterChange: any;
    showBordersChange: any;
    showColumnHeadersChange: any;
    showColumnLinesChange: any;
    showRowLinesChange: any;
    sortByGroupSummaryInfoChange: any;
    sortingChange: any;
    stateStoringChange: any;
    summaryChange: any;
    twoWayBindingEnabledChange: any;
    wordWrapEnabledChange: any;
    columnsChildren: QueryList<DxiColumnComponent>;
    sortByGroupSummaryInfoChildren: QueryList<DxiSortByGroupSummaryInfoComponent>;
    constructor(elementRef: ElementRef, ngZone: NgZone, templateHost: DxTemplateHost, _watcherHelper: WatcherHelper, _idh: IterableDifferHelper, optionHost: NestedOptionHost);
    protected _createInstance(element: any, options: any): DxDataGrid;
    ngOnDestroy(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngDoCheck(): void;
    ngAfterViewInit(): void;
}
export declare class DxDataGridModule {
}

==> devextreme-angular-17.1.4.jar: META-INF/resources/webjars/devextreme-angular/17.1.4/ui/data-grid.d.ts <==
/*!
 * devextreme-angular
 * Version: 17.1.4
 * Build date: Thu Jun 29 2017
 *
 * Copyright (c) 2012 - 2017 Developer Express Inc. ALL RIGHTS RESERVED
 *
 * This software may be modified and distributed under the terms
 * of the MIT license. See the LICENSE file in the root of the project for details.
 *
 * https://github.com/DevExpress/devextreme-angular
 */
import { ElementRef, NgZone, OnDestroy, OnChanges, DoCheck, SimpleChanges, QueryList } from '@angular/core';
import DxDataGrid from 'devextreme/ui/data_grid';
import { DxComponent } from '../core/component';
import { DxTemplateHost } from '../core/template-host';
import { NestedOptionHost } from '../core/nested-option';
import { WatcherHelper } from '../core/watcher-helper';
import { IterableDifferHelper } from '../core/iterable-differ-helper';
import { DxiColumnComponent } from './nested/column-dxi';
import { DxiSortByGroupSummaryInfoComponent } from './nested/sort-by-group-summary-info-dxi';
export declare class DxDataGridComponent extends DxComponent implements OnDestroy, OnChanges, DoCheck {
    private _watcherHelper;
    private _idh;
    instance: DxDataGrid;
    elementAttr: any;
    height: any;
    rtlEnabled: any;
    width: any;
    accessKey: any;
    activeStateEnabled: any;
    disabled: any;
    focusStateEnabled: any;
    hint: any;
    hoverStateEnabled: any;
    tabIndex: any;
    visible: any;
    allowColumnReordering: any;
    allowColumnResizing: any;
    cacheEnabled: any;
    cellHintEnabled: any;
    columnAutoWidth: any;
    columnChooser: any;
    columnFixing: any;
    columnHidingEnabled: any;
    columnMinWidth: any;
    columnResizingMode: any;
    columns: any;
    dataSource: any;
    dateSerializationFormat: any;
    editing: any;
    errorRowEnabled: any;
    filterRow: any;
    headerFilter: any;
    loadPanel: any;
    noDataText: any;
    rowAlternationEnabled: any;
    scrolling: any;
    searchPanel: any;
    selectedRowKeys: any;
    selection: any;
    showBorders: any;
    showColumnHeaders: any;
    showColumnLines: any;
    showRowLines: any;
    sorting: any;
    twoWayBindingEnabled: any;
    wordWrapEnabled: any;
    customizeColumns: any;
    customizeExportData: any;
    export: any;
    grouping: any;
    groupPanel: any;
    keyExpr: any;
    masterDetail: any;
    pager: any;
    paging: any;
    remoteOperations: any;
    rowTemplate: any;
    selectionFilter: any;
    sortByGroupSummaryInfo: any;
    stateStoring: any;
    summary: any;
    onDisposing: any;
    onInitialized: any;
    onOptionChanged: any;
    onContentReady: any;
    onAdaptiveDetailRowPreparing: any;
    onDataErrorOccurred: any;
    onInitNewRow: any;
    onKeyDown: any;
    onRowCollapsed: any;
    onRowCollapsing: any;
    onRowExpanded: any;
    onRowExpanding: any;
    onRowInserted: any;
    onRowInserting: any;
    onRowRemoved: any;
    onRowRemoving: any;
    onRowUpdated: any;
    onRowUpdating: any;
    onRowValidating: any;
    onSelectionChanged: any;
    onToolbarPreparing: any;
    onCellClick: any;
    onCellHoverChanged: any;
    onCellPrepared: any;
    onContextMenuPreparing: any;
    onEditingStart: any;
    onEditorPrepared: any;
    onEditorPreparing: any;
    onExported: any;
    onExporting: any;
    onFileSaving: any;
    onRowClick: any;
    onRowPrepared: any;
    elementAttrChange: any;
    heightChange: any;
    rtlEnabledChange: any;
    widthChange: any;
    accessKeyChange: any;
    activeStateEnabledChange: any;
    disabledChange: any;
    focusStateEnabledChange: any;
    hintChange: any;
    hoverStateEnabledChange: any;
    tabIndexChange: any;
    visibleChange: any;
    allowColumnReorderingChange: any;
    allowColumnResizingChange: any;
    cacheEnabledChange: any;
    cellHintEnabledChange: any;
    columnAutoWidthChange: any;
    columnChooserChange: any;
    columnFixingChange: any;
    columnHidingEnabledChange: any;
    columnMinWidthChange: any;
    columnResizingModeChange: any;
    columnsChange: any;
    dataSourceChange: any;
    dateSerializationFormatChange: any;
    editingChange: any;
    errorRowEnabledChange: any;
    filterRowChange: any;
    headerFilterChange: any;
    loadPanelChange: any;
    noDataTextChange: any;
    rowAlternationEnabledChange: any;
    scrollingChange: any;
    searchPanelChange: any;
    selectedRowKeysChange: any;
    selectionChange: any;
    showBordersChange: any;
    showColumnHeadersChange: any;
    showColumnLinesChange: any;
    showRowLinesChange: any;
    sortingChange: any;
    twoWayBindingEnabledChange: any;
    wordWrapEnabledChange: any;
    customizeColumnsChange: any;
    customizeExportDataChange: any;
    exportChange: any;
    groupingChange: any;
    groupPanelChange: any;
    keyExprChange: any;
    masterDetailChange: any;
    pagerChange: any;
    pagingChange: any;
    remoteOperationsChange: any;
    rowTemplateChange: any;
    selectionFilterChange: any;
    sortByGroupSummaryInfoChange: any;
    stateStoringChange: any;
    summaryChange: any;
    columnsChildren: QueryList<DxiColumnComponent>;
    sortByGroupSummaryInfoChildren: QueryList<DxiSortByGroupSummaryInfoComponent>;
    constructor(elementRef: ElementRef, ngZone: NgZone, templateHost: DxTemplateHost, _watcherHelper: WatcherHelper, _idh: IterableDifferHelper, optionHost: NestedOptionHost);
    protected _createInstance(element: any, options: any): DxDataGrid;
    ngOnDestroy(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngDoCheck(): void;
    _updateOption(name: string, value: any): void;
}
export declare class DxDataGridModule {
}
